#
# spec file for package mono-addins
#
# Copyright (c) 2020 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mono-addins
Version:        1.3.3
Release:        2.52
Summary:        Mono Addins Framework
License:        MIT
Group:          Development/Languages/Mono
URL:            https://github.com/mono/mono-addins
Source:         https://github.com/mono/mono-addins/archive/%{name}-%{version}.tar.gz
Patch0:         fix-delay-sign.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk-sharp-2.0)
BuildRequires:  pkgconfig(mono)
BuildArch:      noarch

%description
Mono.Addins is a generic framework for creating extensible
applications, and for creating libraries which extend those
applications.

%package msbuild
Summary:        Mono Addins Framework, MSBuild Support
Group:          Development/Languages/Mono
Requires:       %{name} = %{version}

%description msbuild
Mono.Addins is a generic framework for creating extensible
applications, and for creating libraries which extend those
applications.

This package contains MSBuild tasks file and target, which allows
using add-in references directly in a build file (still experimental).

%package devel
Summary:        Mono Addins Framework, MSBuild Support
Group:          Development/Languages/Mono
Requires:       %{name} = %{version}

%description devel
Mono.Addins is a generic framework for creating extensible
applications, and for creating libraries which extend those
applications.

This package contains the pkgconfig files.

%prep
%setup -q -n mono-addins-mono-addins-%{version}
%patch0 -p1

%build
./autogen.sh
%configure --libdir=%{_prefix}/lib
%make_build

%install
make install DESTDIR=%{buildroot} GACUTIL_FLAGS="/package mono-addins /root %{buildroot}%{_prefix}/lib"
mkdir -p %{buildroot}%{_datadir}/pkgconfig
mv %{buildroot}%{_prefix}/lib/pkgconfig/*.pc %{buildroot}%{_datadir}/pkgconfig

%files
%{_bindir}/mautil
%{_prefix}/lib/mono/gac/*Mono.Addins
%{_prefix}/lib/mono/gac/*Mono.Addins.Cecil*
%{_prefix}/lib/mono/gac/*Mono.Addins.Gui*
%{_prefix}/lib/mono/gac/*Mono.Addins.Setup*
%dir %{_prefix}/lib/mono/mono-addins
%{_prefix}/lib/mono/mono-addins/mautil.exe
%{_prefix}/lib/mono/mono-addins/Mono.Addins.dll
%{_prefix}/lib/mono/mono-addins/Mono.Addins.Cecil*
%{_prefix}/lib/mono/mono-addins/Mono.Addins.Gui*
%{_prefix}/lib/mono/mono-addins/Mono.Addins.Setup*
%{_mandir}/man1/mautil.1%{?ext_man}

%files msbuild
%{_prefix}/lib/mono/gac/*Mono.Addins.MSBuild*
%{_prefix}/lib/mono/mono-addins/*MSBuild*

%files devel
%{_datadir}/pkgconfig/mono-addins.pc
%{_datadir}/pkgconfig/mono-addins-gui.pc
%{_datadir}/pkgconfig/mono-addins-setup.pc
%{_datadir}/pkgconfig/mono-addins-msbuild.pc

%changelog
* Mon Sep  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Tue Mar  3 2020 Marguerite Su <i@marguerite.su>
- update version 1.3.3
  * bump nuget version
* Tue May  2 2017 fwdsbs.to.11df@xoxy.net
- add fix-delay-sign.patch: check that dll installed to GAC is delay-signed and perform full-sign if so.
- fix build with upcoming mono 5.0: sign delay-signed dlls before adding it to GAC, mono 5.0 is not allowing to install delay-signed dlls into GAC
* Mon Jan  2 2017 t.gruner@katodev.de
- update version 1.3
* Thu Apr 30 2015 fwdsbs.to.11df@xoxy.net
- update version 1.2
  * Fixed bug that caused add-ins to be disabled when being updated.
  * Fixed several issues when scanning assemblies.
  * When evaluating a condition, ensure that the add-in that implements that condition is loaded. This change requires some new information to be stored in the add-in database, so the db version number has been bumped.
  * Fixed assembly resolution bug when running in MS.NET.
  * Added GTK3 implementation of the add-in manager.
  * Registered repositories are now automatically updated the first time the add-in manager is shown.
* Thu Oct 30 2014 i@marguerite.su
- update version 1.1
  * When disabling an add-in, disabled all versions of the add-in
  * Allow embedding .addin files into submodule assemblies
  * Fixed some issue when scanning dlls
  * Added new assembly attributes for defining add-in properties
  * Fixed deadlock when loading add-in roots
  * Fixed GAC assembly directory search for .net 4.0
  * Added support for variables in add-in manifests
  * Updated Cecil from upstream
* Fri Jul  5 2013 mailaender@opensuse.org
- Update to 1.0
  * Fixed crash in ExtensionContext finalizer
  * Minor optimizations
* Tue Jan 29 2013 dimstar@opensuse.org
- Add mono-addins-donet4.patch: Build for .Net 4.0 target.
* Tue Oct  4 2011 nmarques@opensuse.org
- Update to 0.6.2
  + Added option to support non-interactive installations when
    using mautil;
  + Avoid entering in an infinite loop when finding corrupted file;
  + Fixed crash when clicking for add-in info in dynamic assembles;
  + Fix bug in Repair command
* Wed Apr 27 2011 ajorgensen@novell.com
- Update to 0.6.1
  * The 0.6 release of Mono.Addins includes many improvements, bug fixes and new features:
    Add-in engine:
  * Add-in name and description can now be localized. There are new custom attributes for defining them, and can also be specified as xml elements in an add-in manifest instead of attributes.
  * Support for custom add-in properties. It is now possible to specify arbitrary properties in add-ins, which can be queried at install time (using the Mono.Addins.Setup API) or at run-time.
  * Custom extension attributes now allow specifying an extension path. In this way it is now possible to use a single custom attribute to define extensions for different extension points.
  * The default add-in directory and the add-in database directory can now be customized. In previous releases, those directories were always created as a subdirectory of the main registry directory. In this release, the location can be set to any directory.
  * Improved error reporting when a dependency is missing.
  * Added support for specifying the type of the content of string node attributes. This information is used for documentation purposes only.
  * The Cecil based reflector now uses the new Cecil/Light, which is smaller and faster
    Add-in management:
  * Added support for enabling/disabling registered repositories.
  * Added support for downloable support files, to be used for package icons, screenshots, etc.
  * New and improved add-in manager for GTK#. The user interface has been completely redesigned to make it more usable. Add-in updates are more visible and easy to install. The add-in gallery is integrated in the main window, and can show custom add-in icons and preview images.
  * Added new API for accessing custom add-in properties, even before installing them.
  * Included information about download size.
    Bug fixes:
  * Allow overwriting files when installing.
  * Fixed add-in unloading issues.
  * Fixed crash when running in .NET 4.0
  * AddinRepository.LastModified is always 01.01.1900 00:00:00
  * Addin registry access/creation errors when accessed via UNC path
  * Addin discovery/loading fails when running Visual Studio unit tests
  * ImportAddinAssemblyAttribute can't be used multiple times
  * Fix bug in GetAvailableAddin.
  * Fix add-in database issue when the last add-in of a folder is deleted or upgraded
  * Don't allow inheriting CustomExtension attributes. The attribute must be explicitly applied to classes to be marked as extensions.
* Thu Feb 17 2011 gburt@suse.de
- Split off a -msbuild subpackage so the main mono-addins package
  does not depend on mono-devel (bnc#671844)
* Fri Oct 29 2010 ajorgensen@novell.com
- Update to 0.5
  * User defined custom attributes can now be used to declare extensions and add-in metadata.
  * The new AddinEngine class allows hosting several independent add-in engines in a single application domain.
  * Improved lazy loading of add-ins. More information is now lazy loaded.
  * An XML manifest can now be split in several files embedded as resources in an assembly.
  * More add-in information can be declared using custom attributes instead of an XML manifest: author list, imported files and assemblies, optional modules, localizers.
  * Added new API based on generic methods and collections.
  * New MSBuild tasks file and target, which allows using add-in references directly in a build file (still experimental).
  * Reorganized the samples directory.
  * Many bug fixes.
* Thu Nov  6 2008 ajorgensen@novell.com
- Update to 0.4
  * Added support for specifying paths to exclude from the add-in
    scan in .addins files and in add-in manifests.
  * There are several new flags which can be applied to add-ins:
  * Can't uninstall: the add-in can't be uninstalled.
  * Can't disable: the add-in can't be disabled.
  * Hidden: the add-in won't be visible in the setup tools.
  * Fixes in the add-in scanner.
  * The new (and optional) Mono.Addins.CecilReflector assembly
    provides a Cecil-based backend for the add-in scanner. This
    scanner is more reliable than the reflection based scanner.
  * When updating the registry, the add-in scanner will only
    update add-ins belonging to the running application (ignoring
    directories from other instances of the same or different
    applications sharing the same registry).
  * Fixed issue with path length limitation in Windows.
  * Other bug fixes and API improvements.
* Wed Mar 26 2008 wberrier@suse.de
- Update to 0.3.1
  - Fix compatibility with new Mono
  - Delete subdirectory when uninstalling
  - Improve error reporting
* Mon Jan 14 2008 wberrier@suse.de
- Initial package (needed by MD and other mono apps)
